biosiglive.gui package
======================

Submodules
----------

biosiglive.gui.plot module
--------------------------

.. automodule:: biosiglive.gui.plot
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: biosiglive.gui
   :members:
   :undoc-members:
   :show-inheritance:
